@@ -16,6 +16,11 @@ class Corpus():
     def max_phrase_len():
         return 13
 
+    @ring.lru()
+    @staticmethod
+    def words_of_len(k):
+        return Corpus.words()[k]
+
     @ring.lru()
     @staticmethod
     def words():
